@@ -57,8 +57,7 @@ class BalconyServiceSummarizer(BaseBalconyApp,
         def generate_live_render(data):
             nonlocal self
             resource_node_names = [r.get('name') for r in data.get('resource_nodes')]
-            rn_names = data.get('resource_node_names')
-            for ky in kayan_yazi(rn_names):
+            for ky in kayan_yazi(resource_node_names):
                 layout = Layout(Panel(ky), name="main")
                 yield layout
 
